==> leoo_junpro-1.0.1.tar.gz: lib/leooimpjunpro/leooinfojunpro/leoovideolistjunpro.dart <==
import 'dart:async';

import 'package:flutter/material.dart';
import 'package:leoo_junpro/leooflagjunpro/leooentityjunpro/leoouserentity.dart';
import 'package:leoo_junpro/leooflagjunpro/leooentityjunpro/leoovideolistentity.dart';
import 'package:leoo_junpro/leooflagjunpro/leooeventjunpro/leooindexjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooeventjunpro/leoomaineventjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoocodeutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoocommonutilsjunpro.dart';
import 'package:leoo_junpro/leooimpjunpro/leooinfojunpro/leoovideoplayjunpro.dart';
import 'package:leoo_junpro/leoorouterjunpro.dart';
import 'package:preload_page_view/preload_page_view.dart';

///小视频播放界面
class LeooVideoListJunPro extends StatefulWidget {
  static bool leooOpenJunPro = false;
  static int leooIndexJunPro = 0;
  final int position;

  final LeooUserEntity? infoEntity;
  final List<LeooVideoListEntity> videoList;

  const LeooVideoListJunPro(this.position, this.infoEntity, this.videoList,
      {Key? key})
      : super(key: key);

  @override
  _LeooVideoListState createState() => _LeooVideoListState();
}

class _LeooVideoListState extends State<LeooVideoListJunPro>
    with WidgetsBindingObserver, RouteAware {
  late PreloadPageController _pageController;
  List<LeooVideoListEntity> videoList = [];
  late StreamSubscription subscription;
  late StreamSubscription subscriptionFollow;

  @override
  void initState() {
    super.initState();
    LeooVideoListJunPro.leooOpenJunPro = true;
    LeooVideoListJunPro.leooIndexJunPro = widget.position;
    WidgetsBinding.instance?.addObserver(this);
    videoList = widget.videoList;
    _pageController = PreloadPageController(initialPage: widget.position);
    subscription =
        eventBus.on<LeooVideoInfoUnlockEventJunPro>().listen((event) {
      videoList[event.position].unlockStatus = 1;
      LeooCodeUtilsJunPro.onSetState(this);
    });
    subscriptionFollow =
        eventBus.on<LeooVideoInfoFollowEventJunPro>().listen((event) {
      widget.infoEntity?.following = event.following;
      LeooCodeUtilsJunPro.onSetState(this);
    });
  }

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
    LeooRouterJunPro.leooRouteObserverJunPro
        .subscribe(this, ModalRoute.of(context) as PageRoute<dynamic>);
  }

  @override
  void didPopNext() {
    super.didPopNext();
    LeooCommonUtilsJunPro.leooCheckIsCurrentJunPro(context, () {
      eventBus
          .fire(LeooVideoPlayEventJunPro(LeooVideoListJunPro.leooIndexJunPro));
    });
  }

  @override
  void didPushNext() {
    super.didPushNext();
    eventBus.fire(LeooVideoPlayEventJunPro(-1));
  }

  @override
  void dispose() {
    LeooVideoListJunPro.leooOpenJunPro = false;
    WidgetsBinding.instance?.removeObserver(this);
    LeooRouterJunPro.leooRouteObserverJunPro.unsubscribe(this);
    subscription.cancel();
    subscriptionFollow.cancel();
    super.dispose();
  }

  @override
  void didChangeAppLifecycleState(AppLifecycleState state) {
    super.didChangeAppLifecycleState(state);
    if (state == AppLifecycleState.resumed) {
      LeooCommonUtilsJunPro.leooCheckIsCurrentJunPro(context, () {
        eventBus.fire(
            LeooVideoPlayEventJunPro(LeooVideoListJunPro.leooIndexJunPro));
      });
    } else if (state == AppLifecycleState.paused) {
      eventBus.fire(LeooVideoPlayEventJunPro(-1));
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      resizeToAvoidBottomInset: false,
      body: PreloadPageView.builder(
        physics: const BouncingScrollPhysics(),
        controller: _pageController,
        itemCount: videoList.length,
        scrollDirection: Axis.vertical,
        onPageChanged: (index) {
          LeooVideoListJunPro.leooIndexJunPro = index;
          eventBus.fire(LeooVideoPlayEventJunPro(index));
        },
        itemBuilder: (BuildContext context, int index) {
          return LeooVideoPlayJunPro(
            index,
            videoList[index],
            infoEntity: widget.infoEntity,
            play: index == widget.position,
            list: false,
          );
        },
      ),
    );
  }
}

==> leoo_junpro-2.0.0.tar.gz: lib/leooimpjunpro/leooinfojunpro/leoovideolistjunpro.dart <==
import 'dart:async';

import 'package:flutter/material.dart';
import 'package:leoo_junpro/leooflagjunpro/leooentityjunpro/leoouserentity.dart';
import 'package:leoo_junpro/leooflagjunpro/leooentityjunpro/leoovideolistentity.dart';
import 'package:leoo_junpro/leooflagjunpro/leooeventjunpro/leooindexjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooeventjunpro/leoomaineventjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoocodeutilsjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leooutilsjunpro/leoocommonutilsjunpro.dart';
import 'package:leoo_junpro/leooimpjunpro/leooinfojunpro/leoovideoplayjunpro.dart';
import 'package:leoo_junpro/leoorouterjunpro.dart';
import 'package:preload_page_view/preload_page_view.dart';

///小视频播放界面
class LeooVideoListJunPro extends StatefulWidget {
  static bool leooOpenJunPro = false;
  static int leooIndexJunPro = 0;
  final int position;

  final LeooUserEntity? infoEntity;
  final List<LeooVideoListEntity> videoList;

  const LeooVideoListJunPro(this.position, this.infoEntity, this.videoList,
      {Key? key})
      : super(key: key);

  @override
  _LeooVideoListState createState() => _LeooVideoListState();
}

class _LeooVideoListState extends State<LeooVideoListJunPro>
    with WidgetsBindingObserver, RouteAware {
  late PreloadPageController _pageController;
  List<LeooVideoListEntity> videoList = [];
  late StreamSubscription subscription;
  late StreamSubscription subscriptionFollow;

  @override
  void initState() {
    super.initState();
    LeooVideoListJunPro.leooOpenJunPro = true;
    LeooVideoListJunPro.leooIndexJunPro = widget.position;
    WidgetsBinding.instance.addObserver(this);
    videoList = widget.videoList;
    _pageController = PreloadPageController(initialPage: widget.position);
    subscription =
        eventBus.on<LeooVideoInfoUnlockEventJunPro>().listen((event) {
      videoList[event.position].unlockStatus = 1;
      LeooCodeUtilsJunPro.onSetState(this);
    });
    subscriptionFollow =
        eventBus.on<LeooVideoInfoFollowEventJunPro>().listen((event) {
      widget.infoEntity?.following = event.following;
      LeooCodeUtilsJunPro.onSetState(this);
    });
  }

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
    LeooRouterJunPro.leooRouteObserverJunPro
        .subscribe(this, ModalRoute.of(context) as PageRoute<dynamic>);
  }

  @override
  void didPopNext() {
    super.didPopNext();
    LeooCommonUtilsJunPro.leooCheckIsCurrentJunPro(context, () {
      eventBus
          .fire(LeooVideoPlayEventJunPro(LeooVideoListJunPro.leooIndexJunPro));
    });
  }

  @override
  void didPushNext() {
    super.didPushNext();
    eventBus.fire(LeooVideoPlayEventJunPro(-1));
  }

  @override
  void dispose() {
    LeooVideoListJunPro.leooOpenJunPro = false;
    WidgetsBinding.instance.removeObserver(this);
    LeooRouterJunPro.leooRouteObserverJunPro.unsubscribe(this);
    subscription.cancel();
    subscriptionFollow.cancel();
    super.dispose();
  }

  @override
  void didChangeAppLifecycleState(AppLifecycleState state) {
    super.didChangeAppLifecycleState(state);
    if (state == AppLifecycleState.resumed) {
      LeooCommonUtilsJunPro.leooCheckIsCurrentJunPro(context, () {
        eventBus.fire(
            LeooVideoPlayEventJunPro(LeooVideoListJunPro.leooIndexJunPro));
      });
    } else if (state == AppLifecycleState.paused) {
      eventBus.fire(LeooVideoPlayEventJunPro(-1));
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      resizeToAvoidBottomInset: false,
      body: PreloadPageView.builder(
        physics: const BouncingScrollPhysics(),
        controller: _pageController,
        itemCount: videoList.length,
        scrollDirection: Axis.vertical,
        onPageChanged: (index) {
          LeooVideoListJunPro.leooIndexJunPro = index;
          eventBus.fire(LeooVideoPlayEventJunPro(index));
        },
        itemBuilder: (BuildContext context, int index) {
          return LeooVideoPlayJunPro(
            index,
            videoList[index],
            infoEntity: widget.infoEntity,
            play: index == widget.position,
            list: false,
          );
        },
      ),
    );
  }
}
